@@ -302,7 +302,7 @@ class AbinitOutputFile(AbinitTextFile, NotebookWriter):
                         raise ValueError("Don't know how to handle unit: %s" % unit)
 
                 s = " ".join(tokens)
-                dtype = np.float if key not in ("ntypat", "typat", "natom") else np.int
+                dtype = float if key not in ("ntypat", "typat", "natom") else int
                 try:
                     #print(key, s)
                     value = np.fromstring(s, sep=" ", dtype=dtype)
@@ -325,23 +325,23 @@ class AbinitOutputFile(AbinitTextFile, NotebookWriter):
 
             spgid = int(spgd.get("spgroup", 0))
             if "symrel" not in spgd:
-                symrel = np.reshape(np.eye(3, 3, dtype=np.int), (1, 3, 3))
+                symrel = np.reshape(np.eye(3, 3, dtype=int), (1, 3, 3))
                 spgd["symrel"] = " ".join((str(i) for i in symrel.flatten()))
             else:
-                symrel = np.reshape(np.array([int(n) for n in spgd["symrel"].split()], dtype=np.int), (-1, 3, 3))
+                symrel = np.reshape(np.array([int(n) for n in spgd["symrel"].split()], dtype=int), (-1, 3, 3))
             nsym = len(symrel)
             assert nsym == spgd.get("nsym", nsym) #; print(symrel.shape)
 
             if "tnons" in spgd:
-                tnons = np.reshape(np.array([float(t) for t in spgd["tnons"].split()], dtype=np.float), (nsym, 3))
+                tnons = np.reshape(np.array([float(t) for t in spgd["tnons"].split()], dtype=float), (nsym, 3))
             else:
                 tnons = np.zeros((nsym, 3))
 
             if "symafm" in spgd:
-                symafm = np.array([int(n) for n in spgd["symafm"].split()], dtype=np.int)
+                symafm = np.array([int(n) for n in spgd["symafm"].split()], dtype=int)
                 symafm.shape = (nsym,)
             else:
-                symafm = np.ones(nsym, dtype=np.int)
+                symafm = np.ones(nsym, dtype=int)
 
             try:
                 has_timerev = has_timrev_from_kptopt(vars_dataset[i].get("kptopt", global_kptopt))
@@ -570,6 +570,11 @@ class AbinitOutputFile(AbinitTextFile, NotebookWriter):
             """Parse the line with space group info, return dict."""
             # Could use regular expressions ...
             i = line.find("space group")
+
+            if i == -1:
+                # the unit cell is not primitive
+                return {}
+
             spg_str, brav_str = line[i:].replace("space group", "").split(";")
             toks = spg_str.split()
             return {
