@@ -214,7 +214,7 @@ def map_grid2ibz(structure, ibz, ngkpt, has_timrev, pbc=False):
     Returns:
         bz2ibz: 1d array with BZ --> IBZ mapping
     """
-    ngkpt = np.asarray(ngkpt, dtype=np.int)
+    ngkpt = np.asarray(ngkpt, dtype=int)
 
     # Extract (FM) symmetry operations in reciprocal space.
     abispg = structure.abi_spacegroup
@@ -225,10 +225,10 @@ def map_grid2ibz(structure, ibz, ngkpt, has_timrev, pbc=False):
     symrec_fm = [o.rot_g for o in abispg.fm_symmops]
 
     # Compute TS k_ibz.
-    bzgrid2ibz = -np.ones(ngkpt, dtype=np.int)
+    bzgrid2ibz = -np.ones(ngkpt, dtype=int)
 
     for ik_ibz, kibz in enumerate(ibz):
-        gp_ibz = np.array(np.rint(kibz * ngkpt), dtype=np.int)
+        gp_ibz = np.array(np.rint(kibz * ngkpt), dtype=int)
         for rot in symrec_fm:
             rot_gp = np.matmul(rot, gp_ibz)
             gp_bz = rot_gp % ngkpt
@@ -340,7 +340,7 @@ def map_kpoints(other_kpoints, other_lattice, ref_lattice, ref_kpoints, ref_symr
     kmap = collections.namedtuple("kmap", "ik_ref, tsign, isym, g0")
 
     for ik_oth, okpt in enumerate(other_kpoints):
-        # Get other k-point in reduced coordinates in the referece lattice.
+        # Get other k-point in reduced coordinates in the reference lattice.
         okpt_red = np.matmul(ref_gprimd_inv, np.matmul(other_gprimd, okpt))
 
         # k_other = TS k_ref + G0
@@ -457,7 +457,7 @@ def find_irred_kpoints_generic(structure, kfrac_coords, verbose=1):
         print("Entered with ", len(uc_kcoords), "k-points")
         print("Found ", len(irred_map), "irred k-points")
 
-    return dict2namedtuple(irred_map=np.array(irred_map, dtype=np.int))
+    return dict2namedtuple(irred_map=np.array(irred_map, dtype=int))
 
 
 def kpath_from_bounds_and_ndivsm(bounds, ndivsm, structure):
@@ -487,7 +487,7 @@ def kpath_from_bounds_and_ndivsm(bounds, ndivsm, structure):
         raise ValueError("Found two equivalent consecutive points in bounds!")
 
     minlen = minlen / ndivsm
-    ndivs = np.rint(lens / minlen).astype(np.int)
+    ndivs = np.rint(lens / minlen).astype(int)
     path = []
     for i in range(nbounds - 1):
         for j in range(ndivs[i]):
@@ -559,16 +559,26 @@ class Kpoint(SlotPickleMixin):
         "_hash",
     ]
 
+    @classmethod
+    def from_name_and_structure(cls, name, structure):
+        """
+        Build Kpoint object from string with name and structure.
+        """
+        frac_coords = structure.get_kcoords_from_names(name)
+        frac_coords = np.reshape(frac_coords, (3,))
+        return cls(frac_coords, structure.reciprocal_lattice, weight=None, name=name)
+
     def __init__(self, frac_coords, lattice, weight=None, name=None):
         """
         Args:
-            frac_coords: Reduced coordinates.
+            frac_coords: Reduced coordinates of the k-point.
             lattice: |Lattice| object describing the reciprocal lattice.
             weights: k-point weight (optional, set to zero if not given).
             name: string with the name of the k-point (optional)
         """
         self._frac_coords = np.asarray(frac_coords)
-        assert len(self.frac_coords) == 3
+        if len(self.frac_coords) != 3:
+            raise TypeError("Expecting vector with 3 items, got `%s`" % str(self.frac_coords))
 
         self._lattice = lattice
         self.set_weight(weight)
@@ -1117,7 +1127,7 @@ class KpointList(collections.abc.Sequence):
         k2kqg = collections.OrderedDict()
         if np.all(np.abs(qfrac_coords) <= 1e-6):
             # Gamma point, DOH!
-            g0 = np.zeros(3, dtype=np.int)
+            g0 = np.zeros(3, dtype=int)
             for ik, _ in enumerate(self):
                 k2kqg[ik] = (ik, g0)
         else:
@@ -1191,7 +1201,7 @@ class Kpath(KpointList):
         """
         gmet = structure.lattice.reciprocal_lattice.metric_tensor
         vnames = [str(vn[1]) for vn in vertices_names]
-        vertices = np.array([vn[0] for vn in vertices_names], dtype=np.float)
+        vertices = np.array([vn[0] for vn in vertices_names], dtype=float)
         vertices.shape = (-1, 3)
 
         dl_vals = []
@@ -1722,8 +1732,16 @@ class KpointsReaderMixin(object):
 
     def read_kmpdivs(self):
         """Returns the Monkhorst-Pack divisions defining the mesh. None if not found."""
-        #return self.read_value("monkhorst_pack_folding")
-        return self.none_if_masked_array(self.read_value("monkhorst_pack_folding"))
+
+        if "monkhorst_pack_folding" in self.rootgrp.variables:
+            return self.none_if_masked_array(self.read_value("monkhorst_pack_folding"))
+        else:
+            kptrlatt = self.read_kptrlatt()
+            kmpdivs = np.diag(kptrlatt)
+            for i in range(3):
+                for j in range(3):
+                    if i != j and kptrlatt[i, j] != 0: kmpdivs = None
+            return kmpdivs
 
     def read_kptrlatt(self):
         """Returns ABINIT variable kptrlatt. None if not found."""
@@ -1780,7 +1798,7 @@ class Ktables(object):
             is_shift=self.is_shift, is_time_reversal=self.has_timrev, symprec=_SPGLIB_SYMPREC)
 
         uniq, self.weights = np.unique(mapping, return_counts=True)
-        self.weights = np.asarray(self.weights, dtype=np.float) / len(self.grid)
+        self.weights = np.asarray(self.weights, dtype=float) / len(self.grid)
         self.nibz = len(uniq)
         self.kshift = [0., 0., 0.] if is_shift is None else 0.5 * np.asarray(is_shift)
         self.ibz = (self.grid[uniq] + self.kshift) / self.mesh
@@ -1789,7 +1807,7 @@ class Ktables(object):
 
         # All k-points and mapping to ir-grid points.
         # FIXME This is slow.
-        self.bz2ibz = np.empty(len(self.bz), dtype=np.int)
+        self.bz2ibz = np.empty(len(self.bz), dtype=int)
         for ik_bz, ir_gp_id in enumerate(mapping):
             inds = np.where(uniq == ir_gp_id)
             assert len(inds) == 1
@@ -1836,6 +1854,7 @@ def dist_point_from_line(x0, x1, x2):
 def find_points_along_path(cart_bounds, cart_coords, dist_tol):
     """
     Find points in ``cart_coords`` lying on the path defined by ``cart_bounds``.
+    Result are ordered according to distance along the path.
 
     Args:
         cart_bounds: [N, 3] array with the boundaries of the path in Cartesian coordinates.
