@@ -762,7 +762,7 @@ def main():
     elif options.command == "panel":
         structure = abilab.Structure.from_file(options.filepath)
         try:
-            import panel  # flake8: noqa
+            import panel  # noqa: F401
         except ImportError as exc:
             cprint("Use `conda install panel` or `pip install panel` to install the python package.", "red")
             raise exc
